@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package IPv6::Address;
-$IPv6::Address::VERSION = '0.203';
+$IPv6::Address::VERSION = '0.204';
 
 =head1 NAME
 
@@ -10,7 +10,7 @@ IPv6::Address - IPv6 Address Manipulation Library
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =for html
 <a href="https://travis-ci.org/aduitsis/IPv6-Address"><img src="https://travis-ci.org/aduitsis/IPv6-Address.svg?branch=master"></a>
@@ -635,7 +635,7 @@ sub radius_string {
 }
 
 package IPv4Subnet;
-$IPv4Subnet::VERSION = '0.203';
+$IPv4Subnet::VERSION = '0.204';
 use Socket;
 use strict;
 use Carp;
@@ -682,6 +682,10 @@ sub get_length {
 	return 2**(32-$_[0]->get_length_n);
 }
 
+sub enumerate {
+	map { my_ntoa( $_ ) } ($_[0]->get_start .. $_[0]->get_stop)
+}
+
 sub get_length_n {
 	return $_[0]->{length_n};
 }
